@@ -14,12 +14,16 @@
 #ifndef _KOPETE_VERSION_H_
 #define _KOPETE_VERSION_H_
 
-#define KOPETE_VERSION_STRING "1.8.3"
 #define KOPETE_VERSION_MAJOR 1
 #define KOPETE_VERSION_MINOR 8
-#define KOPETE_VERSION_RELEASE 3
+#define KOPETE_VERSION_RELEASE 80
+
+#define KOPETE_STRINGIFY(a) #a
+#define KOPETE_MAKE_VERSION_STRING( a,b,c ) KOPETE_STRINGIFY(a.b.c)
 #define KOPETE_MAKE_VERSION( a,b,c ) (((a) << 16) | ((b) << 8) | (c))
 
+#define KOPETE_VERSION_STRING \
+  KOPETE_MAKE_VERSION_STRING(KOPETE_VERSION_MAJOR,KOPETE_VERSION_MINOR,KOPETE_VERSION_RELEASE)
 #define KOPETE_VERSION \
   KOPETE_MAKE_VERSION(KOPETE_VERSION_MAJOR,KOPETE_VERSION_MINOR,KOPETE_VERSION_RELEASE)
 
